# sqlite2pg

An Sqlite3 to Postgresql database migration tool.

## A warning

This project is still in very early development, and will not be ready until the v1.0 release.
Please refrain from using sqlite2pg for now.

## Why sqlite2pg

 - An easy to use command line interface.
 - Options to accomodate different use cases.
 - Complete full migrations, or just generate schema.
 - Asynchronous, keeping performance in mind for big jobs.

## Installation

sqlite2pg requires python 3.8.0 or greater.

To get started:
```bash
pip install sqlite2pg
```

## License

sqlite2pg is licensed under the [BSD 3-Clause License](https://github.com/Jonxslays/sqlite2pg/blob/master/LICENSE).
